@@ -6,6 +6,8 @@
 */
 
 #include "environmentsettingsrulespage.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "environmentplaintextedit.h"
 #include <KLocalizedString>
 #include <QVBoxLayout>
@@ -17,7 +19,7 @@ EnvironmentSettingsRulesPage::EnvironmentSettingsRulesPage(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins({});
     mRichTextEdit->setReadOnly(true);
-    mRichTextEdit->setObjectName(QLatin1StringView("richtext"));
+    mRichTextEdit->setObjectName("richtext"_L1);
     mainLayout->addWidget(mRichTextEdit);
 }
 
@@ -25,10 +27,10 @@ EnvironmentSettingsRulesPage::~EnvironmentSettingsRulesPage() = default;
 
 void EnvironmentSettingsRulesPage::setRules(const QString &rules)
 {
-    const QString information = QLatin1String("<qt><b>")
-        + i18n("These rules cannot be edited with this application. You need to set them in QT_LOGGING_RULES variable directly.") + QLatin1String("</b><qt>");
+    const QString information =
+        "<qt><b>"_L1 + i18n("These rules cannot be edited with this application. You need to set them in QT_LOGGING_RULES variable directly.") + "</b><qt>"_L1;
     QString newRules = rules;
-    mRichTextEdit->setHtml(information + i18n("Current rules:") + QStringLiteral("<br>") + newRules.replace(QLatin1Char('\n'), QLatin1String("<br>")));
+    mRichTextEdit->setHtml(information + i18n("Current rules:") + QStringLiteral("<br>") + newRules.replace(QLatin1Char('\n'), "<br>"_L1));
 }
 
 #include "moc_environmentsettingsrulespage.cpp"
